/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.api.session;

import java.io.Serializable;

/**
 * Identifies one Data Object. 
 * To be used for storing data objects in the Cache. 
 * @author ldo
 *
 */
public class DataObjectIdentifier implements Serializable {

	/**
	 * TODO: change to generated
	 */
	private static final long serialVersionUID = -1L;

	final String _user;
	final String _device;
	final String _objectID;
	final long _timestamp;

	public DataObjectIdentifier(String user, String device, String objectID, long timestamp) {
		_user = user;
		_device = device;
		_objectID = objectID;
		_timestamp = timestamp;
	}

	public String getUser() {
		return _user;
	}

	public String getDevice() {
		return _device;
	}

	public String getObjectID() {
		return _objectID;
	}

	public long getTimestamp() {
		return _timestamp;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		DataObjectIdentifier other = (DataObjectIdentifier) obj;
		if (!_user.equals(other._user))
			return false;
		if (!_device.equals(other._device))
			return false;
		if (!_objectID.equals(other._objectID))
			return false;
		if (_timestamp != other._timestamp)
			return false;
		return true;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + _user.hashCode();
		result = prime * result + _device.hashCode();
		result = prime * result + _objectID.hashCode();
		result = prime * result + (int) _timestamp;
		return result;
	}

	@Override
	public String toString() {
		return _user + ':' + _device + ':' + _objectID + ':' + _timestamp;
	}
}
