/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.resources.impl;

import java.util.*;

import org.apache.commons.logging.Log;
import org.json.*;

import com.openexchange.usm.api.contenttypes.*;
import com.openexchange.usm.api.exceptions.InternalUSMException;
import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.api.session.*;
import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
import com.openexchange.usm.contenttypes.util.UtilConstants;
import com.openexchange.usm.ox_json.*;

public class ResourcesContentTypeTransferHandler extends AbstractTransferHandler {

	protected ResourcesContentTypeTransferHandler(ContentType contentType, Log journal, OXJSONAccess ajaxAccess) {
		super(contentType, journal, ajaxAccess);
	}

	@Override
	protected String getOXAjaxAccessPath() {
		return ResourcesConstants.RESOURCES_PATH;
	}

	@Override
	public void writeNewDataObject(DataObject object) throws USMException {
		if (_journal.isErrorEnabled())
			_journal.error(object.getSession() + " Creating a resource is not supported");
		throw new UnsupportedContentOperationException(USMContentTypesResourcesErrorCodes.CREATE_ERROR,
				"Creating a resource is not supported");
	}

	@Override
	public void writeUpdatedDataObject(DataObject object, long timestamp) throws USMException {
		if (_journal.isErrorEnabled())
			_journal.error(object.getSession() + " Updating a resource is not supported");
		throw new UnsupportedContentOperationException(USMContentTypesResourcesErrorCodes.UPDATE_ERROR,
				"Updating a resource is not supported");
	}

	@Override
	public void writeDeletedDataObject(DataObject object) throws USMException {
		if (_journal.isErrorEnabled())
			_journal.error(object.getSession() + " Deleting a resource is not supported");
		throw new UnsupportedContentOperationException(USMContentTypesResourcesErrorCodes.DELETE_ERROR,
				"Deleting a resource is not supported");
	}

	@Override
	public DataObject[] readUpdatedFolderContent(Folder folder, BitSet requestedFields, long timestamp)
			throws USMException {
		if (_journal.isErrorEnabled())
			_journal.error(folder.getSession() + " Updating a folder content is not supported for resources");
		throw new UnsupportedContentOperationException(USMContentTypesResourcesErrorCodes.UPDATE_FOLDER_ERROR,
				"Updating a folder content is not supported for resources");
	}

    @Override
    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
        return new OXFolderContent(true, readFolderContent(folder, folder.getSession().getFieldFilter(folder.getElementsContentType())));
    }

	@Override
	public DataObject[] readFolderContent(Folder folder, BitSet requestedFields) throws USMException {
		Session session = folder.getSession();
		if (_journal.isDebugEnabled())
			_journal.debug(session + " Read all " + _contentType.getID());
		Map<String, String> parameters = new HashMap<String, String>();
		JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters);
		checkResult(result, JSONResultType.JSONObject);
		JSONArray identifiersArray = extractArrayResult(result);
		JSONArray requestBody = new JSONArray();
		int length = identifiersArray.length();
		for (int i = 0; i < length; i++) {
			JSONObject obj = new JSONObject();
			try {
				obj.put(UtilConstants.ID, identifiersArray.getString(i));
			} catch (JSONException e) {
				throw new InternalUSMException(USMContentTypesResourcesErrorCodes.CREATE_REQUEST_ERROR,
						"Error on creating request body", e);
			}
			requestBody.put(obj);
		}
		JSONResult result2 = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_LIST, session, parameters,
				requestBody);
		checkResult(result2, JSONResultType.JSONObject);
		JSONArray resourcesArray = extractArrayResult(result2);
		long timestamp = result.getJSONObject().optLong(UtilConstants.TIMESTAMP, System.currentTimeMillis());
		int length2 = resourcesArray.length();
		DataObject[] resultArray = new DataObject[length2];
		try {
			for (int i = 0; i < length2; i++) {
				JSONObject jsonObj = resourcesArray.getJSONObject(i);
				resultArray[i] = _contentType.newDataObject(session);
				resultArray[i].setTimestamp(timestamp);
				ContentTypeField[] fields = _contentType.getFields();
				for (int j = 0; j < fields.length; j++) {
					ContentTypeField field = fields[j];
					String fieldName = field.getFieldName();
					resultArray[i].setFieldContent(fieldName, field.getFieldType().extractFromJSONObject(session,
							jsonObj, fieldName));
				}
			}
		} catch (JSONException e) {
			throw new InternalUSMException(USMContentTypesResourcesErrorCodes.READ_RESULT_ERROR,
					"Error on reading result", e);
		}
		return resultArray;
	}

}
